pub struct TopicCollection { /* private fields */ }Expand description
Represents a collection of topics.
This is used to subscribe to multiple topics at once.
Examples
use nt_client::Client;
let client = Client::new(Default::default());
client.connect_setup(setup).await.unwrap();
fn setup(client: &Client) {
let topics = client.topics(vec![
"/topic".to_owned(),
"/nested/topic".to_owned(),
"/deeply/nested/topic".to_owned(),
]);
tokio::spawn(async move {
let subscriber = topics.subscribe(Default::default()).await;
// do something with subscriber...
});
}Implementations
Sourceimpl TopicCollection
impl TopicCollection
Sourcepub fn names_mut(&mut self) -> &mut Vec<String>
pub fn names_mut(&mut self) -> &mut Vec<String>
Returns a mutable slice of topic names this collection contains.
Sourcepub async fn subscribe(
&self,
options: SubscriptionOptions,
) -> Result<Subscriber, ConnectionClosedError>
pub async fn subscribe( &self, options: SubscriptionOptions, ) -> Result<Subscriber, ConnectionClosedError>
Subscribes to this collection of topics.
This method does not require the Client websocket connection to be made.